var util = require('util');
var htmlScanner = require('./html_scanner');

var TEMPLATE = 'angular.module(\'%s\', []).run(function($templateCache) {\n' +
    '  $templateCache.put(\'%s\',\n    \'%s\');\n' +
    '});\n';

var SINGLE_MODULE_TPL = '(function(module) {\n' +
    'try {\n' +
    '  module = angular.module(\'%s\');\n' +
    '} catch (e) {\n' +
    '  module = angular.module(\'%s\', []);\n' +
    '}\n' +
    'module.run(function($templateCache) {\n' +
    '  $templateCache.put(\'%s\',\n    \'%s\');\n' +
    '});\n' +
    '})();\n';

var escapeContent = function(content) {
  return content.replace(/\\/g, '\\\\').replace(/'/g, '\\\'').replace(/\r?\n/g, '\\n\' +\n    \'');
};

var createHtml2JsPreprocessor = function(logger, basePath, config) {
  config = typeof config === 'object' ? config : {};

  var log = logger.create('preprocessor.html2js');
  var moduleName = config.moduleName;

  return function(content, file, done) {
    log.debug('Processing "%s".', file.originalPath);

    file.path = file.path + '.js';

    var results = htmlScanner.scan(content, file.originalPath);
    var output = '';
    results.forEach(function (template) {
      var templateId = template.name;

      if (moduleName) {
        output += util.format(SINGLE_MODULE_TPL, moduleName, moduleName, templateId, escapeContent(template.contents));
      } else {
        output += util.format(TEMPLATE, templateId, templateId, escapeContent(template.contents));
      }
    });

    done(output);
  };
};

createHtml2JsPreprocessor.$inject = ['logger', 'config.basePath', 'config.angularTemplatingHtml2JsPreprocessor'];

module.exports = createHtml2JsPreprocessor;
